@@ -1,4 +1,5 @@
-import React, { PropTypes, Component } from 'react';
+import React, { Component } from 'react';
+import PropTypes from 'prop-types';
 import { requireNativeComponent, processColor } from 'react-native';
 import { getActualSource } from '../utils';
 const TRIMMER_COMPONENT_NAME = 'RNTrimmerView';
